@@ -1,4 +1,4 @@
-#include <config.h>
+
 #include "getters.hpp"
 
 namespace lisp
@@ -15,7 +15,7 @@ bool get(const Lisp* lisp, bool& val)
 bool get(const Lisp* lisp, float& val)
 {
   if(lisp->get_type() == Lisp::TYPE_INT)
-    val = (float)lisp->get_int();
+    val = static_cast<float>(lisp->get_int());
   else if(lisp->get_type() == Lisp::TYPE_FLOAT)
     val = lisp->get_float();
   else
